@@ -6,20 +6,27 @@ use warnings;
 
 =head1 NAME
 
-Acme::phillup - Test module for YAPC::NA 2012
+Acme::phillup - The great new Acme::phillup!
 
 =head1 VERSION
 
-Version 0.02
+Version 0.01
 
 =cut
 
-our $VERSION = '0.02_02';
+our $VERSION = '0.01';
 
 
 =head1 SYNOPSIS
 
-This is just a quickie module being created during a workshop at YAPC::NA 2012 by brian d foy
+Quick summary of what the module does.
+
+Perhaps a little code snippet.
+
+    use Acme::phillup;
+
+    my $foo = Acme::phillup->new();
+    ...
 
 =head1 EXPORT
 
